@@ -30,7 +30,9 @@ eval <<'__PP__' if $pp;
 for ( qw: country_code country_code3 country_name
           region       region_name   city
           postal_code  dma_code      area_code 
-          latitude     longitude     continent_code           : ) {
+          latitude     longitude     continent_code
+		  metro_code                                   : ) {
+
   no strict   qw/ refs /;
   no warnings qw/ redefine /;
   my $m = $_; # looks bogus, but it is not! it is a copy not a alias
